Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(758)

Unified Diff: media/renderers/renderer_impl.h

Issue 1423163004: media: Replace DecryptorReadyCB with CdmReadyCB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments addressed Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/renderers/audio_renderer_impl_unittest.cc ('k') | media/renderers/renderer_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/renderers/renderer_impl.h
diff --git a/media/renderers/renderer_impl.h b/media/renderers/renderer_impl.h
index 56887c2a53c0861ddbd235d1d9a07903f788026a..ccaabbe1d12f21342b9280c3dcb0fafcc2dbae30 100644
--- a/media/renderers/renderer_impl.h
+++ b/media/renderers/renderer_impl.h
@@ -85,11 +85,11 @@ class MEDIA_EXPORT RendererImpl : public Renderer {
bool GetWallClockTimes(const std::vector<base::TimeDelta>& media_timestamps,
std::vector<base::TimeTicks>* wall_clock_times);
// Requests that this object notifies when a decryptor is ready through the
// |decryptor_ready_cb| provided.
// If |decryptor_ready_cb| is null, the existing callback will be fired with
// nullptr immediately and reset.
- void SetDecryptorReadyCallback(const DecryptorReadyCB& decryptor_ready_cb);
+ void SetCdmReadyCallback(const CdmReadyCB& cdm_ready_cb);
// Helper functions and callbacks for Initialize().
void InitializeAudioRenderer();
@@ -170,12 +170,12 @@ class MEDIA_EXPORT RendererImpl : public Renderer {
CdmContext* cdm_context_;
// Callback registered by filters (decoder or demuxer) to be informed of a
- // Decryptor.
+ // CDM.
// Note: We could have multiple filters registering this callback. One
// callback is okay because:
// 1, We always initialize filters in sequence.
// 2, Filter initialization will not finish until this callback is satisfied.
- DecryptorReadyCB decryptor_ready_cb_;
+ CdmReadyCB cdm_ready_cb_;
bool underflow_disabled_for_testing_;
bool clockless_video_playback_enabled_for_testing_;
« no previous file with comments | « media/renderers/audio_renderer_impl_unittest.cc ('k') | media/renderers/renderer_impl.cc » ('j') | no next file with comments »
@@ -85,11 +85,11 @@ class MEDIA_EXPORT RendererImpl : public Renderer {
bool GetWallClockTimes(const std::vector<base::TimeDelta>& media_timestamps,
std::vector<base::TimeTicks>* wall_clock_times);
- // Requests that this object notifies when a decryptor is ready through the
- // |decryptor_ready_cb| provided.
- // If |decryptor_ready_cb| is null, the existing callback will be fired with
+ // Requests that this object notifies when a CDM is ready through the
+ // |cdm_ready_cb| provided.
+ // If |cdm_ready_cb| is null, the existing callback will be fired with
// nullptr immediately and reset.

Powered by Google App Engine
This is Rietveld 408576698